    function I = int_spline_cubique(xi, fxi, fpp)
%
%  Intégration à l'aide des splines cubiques (de x_0 a x_n)
%  Programmeur: A. Lioret 
%  Référence: Analyse numérique pour ingénieurs, A. Fortin,
%             Presses internationales Polytechnique, 
%             Cinquième édition, 2015
%             Section 6.4.4
%
%  function I = int_spline_cubique(xi, fxi, fpp)
%  Arguments
%
%  Entrée:
%  1) xi: Un vecteur ligne contenant les abscisses xi
%     qui servent à construire la spline.
%     Exemple: xi = [1 2 4 5].
%  2) fxi: Un vecteur ligne contenant les valeurs f(xi)
%     de la fonction à interpoler pour les xi correspondants. 
%     Exemple: fxi = [1 4 9 11].
%  3) fpp: Le vecteur des dérivees secondes de la spline 
%     calculées à l'aide de la fonction spline_cubique.
%  Retour:
%  1) I: Valeur calculée de l'intégrale définie.
%
%  Préalable:
%  Vous devez d'abord calculer les dérivées secondes de la 
%  spline cubique utilisée, à l'aide de la fonction spline_cubique.
%  Exemple: fpp tel que 
%  [S, fpp] = spline_cubique([1 2 4 5], [1 4 9 11], 'n', []).
%   
%  Exemple d'appel:
%  I = int_spline_cubique([1 2 4 5], [1 4 9 11], fpp)

    n = length(xi);
    hi = diff(xi);
    yi1 = fxi(1:n-1) + fxi(2:n);
    yi2 = fpp(1:n-1)' + fpp(2:n)';
    H1 = hi./2;
    H2 = hi.^3./24;
    I = H1*yi1' - H2*yi2';





