    function I = int_trapezes(f, a, b, n)
%
%  Méthode des trapèzes composée
%  Programmeur: A. Lioret 
%  Référence: Analyse numérique pour ingénieurs, A. Fortin,
%             Presses internationales Polytechnique, 
%             Cinquième édition, 2015
%             Section 6.4.1
%
%  function I = int_trapezes(f, a, b, n)
%
%  Arguments
%  Entrée:
%  1) f: Vous devez fournir soit le nom entre apostrophes (' ') du 
%     fichier .m  contenant la fonction à intégrer, 
%     soit une fonction anonyme comme par exemple
%     f_anonyme = @(x) x.*x -2;
%     soit les valeurs de la fonction aux points d'intégration 
%     dans un vecteur ligne (f_vecteur), correspondant avec
%     le nombre de sous-intervalles utilisés (si on a N sous-intervalles,
%     on doit avoir N+1 valeurs de la fonction à intégrer).
%  2) a: La borne inférieure de l'intervalle d'intégration.
%  3) b: La borne supérieure de l'intervalle d'intégration.
%  4) N: Le nombre de sous-intervalles utilisés.
%  Retour:
%  1) I: Valeur calculée de l'intégrale définie. 
%
%  Préalable:
%  Si vous connaissez la fonction à intégrer, vous pouvez créer
%  un fichier .m contenant cette fonction.
%  Voir par exemple le fichier fonc.m. Alternativement, vous pouvez aussi
%  utiliser une fonction anonyme ou un vecteur.
%
%  Exemples d'appel:
%  I = int_trapezes('fonc',    0, 2, 8)
%  I = int_trapezes(f_anonyme, 0, 2, 8)
%  I = int_trapezes(f_vecteur, 0, 2, 8)
%
    if (n <= 0)
      error('n doit être positif');
    end
    h = (b - a)/n;

    if (ischar(f) || isa(f, 'function_handle') == 1)
      f=fcnchk(f);
      x = a:h:b;
      fx = feval(f, x);
      if ~(all(isfinite(fx)))
        error('La fonction n''est pas définie pour certains points évalués');
      end
    else
      l = length(f);
      if (l ~= n+1)
        error('Le nombre de points fournis ne correspond pas avec le nombre de sous-intervalles');
      end
      fx = f;
    end
    yi0 = fx(1) + fx(n+1);
    yi1 = fx(2:n);
 
    I = h/2*(yi0 + 2*sum(yi1));
